\name{Ecoli.HS}
\alias{Ecoli.HS}
\alias{Ecoli.HS.raw}
\title{Ecoli heat shock data from Richmond et al. (1999)}
\usage{example(Ecoli.HS)}
\format{
    A data frame with 4253 observations on 3 variables.
    \tabular{rlll}{
	[,1] \tab identifier \tab   factor \tab  probe identifier\cr
	[,2] \tab Cy3 \tab numeric \tab normalized Cy3 intensity\cr
	[,3] \tab Cy5 \tab numeric \tab normalized Cy5 intensity
}}
\details{These data represent 4 chips under control, IPTG-a, IPTG-b and
    heat shock. The \code{raw} data are normalized using
    \code{Ecoli.norm}.}
\source{CS Richmond, Department of Genetics, UW-Madison}
\references{CS Richmond, JD Glasner, R Mau, H Jin and FR Blattner (1999)
    Genome-wide expression profiling in \emph{Escherichia coli} K-12.
    \emph{Nucleic Acids Research} 27(19): 3821-3835.
    \\
    Newton MA, Kendziorski CM, Richmond CS, Blattner FR, Tsui KW (2001)
    On differential variability of expression ratios: Improving
    statistical inference about gene
    expression changes from microarray data. \emph{J Comp Biol 8}: 37-52.
}
\seealso{\code{\link{Ecoli}}, \code{\link{Ecoli.pickgene}},
    \code{\link{Ecoli.oddsplot}}}
\examples{
library( pickgene )
library( Ecoli )

#analysis of HS

data( Ecoli.HS )
twoarray.plot( Ecoli.HS, main = "Heat Shock",
  theta = c(2.7528,1.3661,4.1240,0.0515) )
}
\name{Ecoli.IPTGa}
\alias{Ecoli.IPTG}
\alias{Ecoli.IPTGa}
\alias{Ecoli.IPTGb}
\alias{Ecoli.IPTG.raw}
\title{Ecoli IPTG data from Richmond et al. (1999)}
\usage{example(Ecoli.IPTGa)}
\format{
    A data frame with 4253 observations on 3 variables.
    \tabular{rlll}{
	[,1] \tab identifier \tab   factor \tab  probe identifier\cr
	[,2] \tab Cy3 \tab numeric \tab normalized Cy3 intensity\cr
	[,3] \tab Cy5 \tab numeric \tab normalized Cy5 intensity
}}
\details{These data represent 4 chips under control, IPTG-a, IPTG-b and
    heat shock. The \code{raw} data are normalized using
    \code{Ecoli.norm}.}
\source{CS Richmond, Department of Genetics, UW-Madison}
\references{CS Richmond, JD Glasner, R Mau, H Jin and FR Blattner (1999)
    Genome-wide expression profiling in \emph{Escherichia coli} K-12.
    \emph{Nucleic Acids Research} 27(19): 3821-3835.
    \\
    Newton MA, Kendziorski CM, Richmond CS, Blattner FR, Tsui KW (2001)
    On differential variability of expression ratios: Improving
    statistical inference about gene
    expression changes from microarray data. \emph{J Comp Biol 8}: 37-52.
}
\seealso{\code{\link{Ecoli}}, \code{\link{Ecoli.pickgene}},
    \code{\link{Ecoli.oddsplot}}}
\examples{
library( pickgene )
library( Ecoli )

#analysis of IPTGa

data( Ecoli.IPTGa )
twoarray.plot( Ecoli.IPTGa, main = "IPTG-a",
  theta = c(12.5348,0.8163,0.3707,0.0069) )

#analysis of IPTGb

data( Ecoli.IPTGb )
twoarray.plot( Ecoli.IPTGb, main = "IPTG-b",
  theta = c(9.6886,0.6786,0.2844,0.0036) )
}
\name{Ecoli}
\alias{Ecoli}
\title{Ecoli data from Richmond et al.}
\usage{data(Ecoli)}
\format{
    A data frame with 4253 observations on 3 variables.
    \tabular{rlll}{
	[,1] \tab identifier \tab   factor \tab  probe identifier\cr
	[,2] \tab Cy3 \tab numeric \tab normalized Cy3 intensity\cr
	[,3] \tab Cy5 \tab numeric \tab normalized Cy5 intensity
}}
\details{These data represent 4 chips under control, IPTG-a, IPTG-b and
    heat shock. The \code{raw} data are normalized using
    \code{Ecoli.norm}.}
\source{CS Richmond, Department of Genetics, UW-Madison}
\references{CS Richmond, JD Glasner, R Mau, H Jin and FR Blattner (1999)
    Genome-wide expression profiling in \emph{Escherichia coli} K-12.
    \emph{Nucleic Acids Research} 27(19): 3821-3835.
}
\seealso{\code{\link{Ecoli.pickgene}},\code{\link{Ecoli.oddsplot}}}
\examples{
library( Ecoli )
data( Ecoli.contol )
data( Ecoli.IPTGa )
data( Ecoli.IPTGb )
data( Ecoli.HS )
}
% Converted by  version .

\name{Ecoli.control}
\alias{Ecoli.control}
\alias{Ecoli.control.raw}
\title{E. coli control data from Richmond et al. (1999)}
\usage{example(Ecoli.control)}
\format{
    A data frame with 4253 observations on 3 variables.
    \tabular{rlll}{
	[,1] \tab identifier \tab   factor \tab  probe identifier\cr
	[,2] \tab Cy3 \tab numeric \tab normalized Cy3 intensity\cr
	[,3] \tab Cy5 \tab numeric \tab normalized Cy5 intensity
}}
\details{These data represent 4 chips under control, IPTG-a, IPTG-b and
    heat shock. The \code{raw} data are normalized using
    \code{Ecoli.norm}.}
\source{CS Richmond, Department of Genetics, UW-Madison}
\references{CS Richmond, JD Glasner, R Mau, H Jin and FR Blattner (1999)
    Genome-wide expression profiling in \emph{Escherichia coli} K-12.
    \emph{Nucleic Acids Research} 27(19): 3821-3835.
    \\
    Newton MA, Kendziorski CM, Richmond CS, Blattner FR, Tsui KW (2001)
    On differential variability of expression ratios: Improving
    statistical inference about gene
    expression changes from microarray data. \emph{J Comp Biol 8}: 37-52.
}
\seealso{\code{\link{Ecoli}}, \code{\link{Ecoli.pickgene}},
    \code{\link{Ecoli.oddsplot}}}
\examples{
library( pickgene )
library( Ecoli )

#analysis of control

data( Ecoli.control )
twoarray.plot( Ecoli.control, main = "Control",
  theta = c(22.9048,0.9438,0.2847,0.0030) )
}
\name{Ecoli.oddsplot}
\alias{Ecoli.oddsplot}
\title{Ecoli data Odds Plot analysis using Gamma-Gamma model}
\usage{data(Ecoli)}
\format{
  Odds plot analysis of E. coli microarray data using Bayesian
  Gamma-Gamma-Bernoulli model.
}
\source{Craig Richmond}
\references{MA Newton, CM Kendziorski, CS Richmond, FR Blattner and KW
    Tsui (2000) ``On differential variability of expression ratios:
    improving statistical inference about gene expression changes from
    microarray data,''
	\emph{J Computational Biology 00}: 000-000.}
\seealso{\code{\link{Ecoli}}, \code{\link{oddsplot}}, \code{\link{em.ggb}}}
\examples{
library( pickgene )
library( Ecoli )

par( mfrow = c(2,2) )

data( Ecoli.control )
do.oddsplot( Ecoli.control, "Control", rotate = F,
  theta = c(22.9048,0.9438,0.2847,0.0030) )

data( Ecoli.HS )
do.oddsplot( Ecoli.HS, "Heat Shock", rotate = F,
  theta = c(2.7528,1.3661,4.1240,0.0515) )

data( Ecoli.IPTGa )
do.oddsplot( Ecoli.IPTGa, "IPTG-a", rotate = F,
  theta = c(12.5348,0.8163,0.3707,0.0069) )

data( Ecoli.IPTGb )
do.oddsplot( Ecoli.IPTGb, "IPTG-b", rotate = F,
  theta = c(9.6886,0.6786,0.2844,0.0036) )
}
% Converted by  version .

\name{Ecoli.pickgene}
\alias{Ecoli.pickgene}
\title{Pickgene analysis of Richmond et al. (1999) E. coli data}
\usage{example(Ecoli.pickgene)}
\details{}
\seealso{\code{\link{Ecoli}}, \code{\link{pickgene}},
    \code{\link{robustscale}}, \code{\link{Ecoli.plot}}}
\examples{
library( pickgene )
library( Ecoli )

#analysis of control

data( Ecoli.control )
data( Ecoli.IPTGa )
data( Ecoli.IPTGb )
data( Ecoli.HS )

pickgene( Ecoli.control[,c("Cy3","Cy5")],
  Ecoli.control$identifier, facnames = "Control",
  mfrow = c(2,2) )$pick
title( "Control" )

pickgene( Ecoli.HS[,c("Cy3","Cy5")],
  Ecoli.HS$identifier, facnames = "HeatShock",
  mfrow = NULL )$pick
title( "Heat Shock" )

pickgene( Ecoli.IPTGa[,c("Cy3","Cy5")],
  Ecoli.IPTGa$identifier, facnames = "IPTGa",
  mfrow = NULL )$pick
title( "IPTG-a" )

pickgene( Ecoli.IPTGb[,c("Cy3","Cy5")],
  Ecoli.IPTGb$identifier, facnames = "IPTGb",
  mfrow = NULL )$pick
title( "IPTG-b" )
}
